
# Type: has attribute


connects any named thing to an attribute

URI: [biolink:has_attribute](https://w3id.org/biolink/vocab/has_attribute)


## Domain and Range

None ->  <sub>0..*</sub> [Attribute](Attribute.md)

## Parents


## Children


## Used by

 * [MaterialSample](MaterialSample.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | SIO:000008 |
|  | | RO:0000053 |
| **In Subsets:** | | samples |

